@@ -11,10 +11,8 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::CommitBuild;
-{
-  $Dist::Zilla::Plugin::Git::CommitBuild::VERSION = '2.018'; # TRIAL
-}
 # ABSTRACT: checkin build results on separate branch
+$Dist::Zilla::Plugin::Git::CommitBuild::VERSION = '2.032'; # TRIAL
 
 use Git::Wrapper 0.021 ();      # need -STDIN
 use IPC::Open3;
@@ -24,9 +22,8 @@ use File::Spec::Functions qw/ rel2abs catfile /;
 use File::Temp;
 use Moose;
 use namespace::autoclean;
-use MooseX::AttributeShortcuts;
-use Path::Class 0.22;           # dir->basename
-use MooseX::Types::Path::Class ':all';
+use Path::Tiny qw();
+use MooseX::Types::Path::Tiny qw( Path );
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ Str };
 use Cwd qw(abs_path);
@@ -63,7 +60,7 @@ has branch  => ( ro, isa => Str, default => 'build/%b', required => 1 );
 has release_branch  => ( ro, isa => Str, required => 0 );
 has message => ( ro, isa => Str, default => 'Build results of %h (on %b)', required => 1 );
 has release_message => ( ro, isa => Str, lazy => 1, builder => '_build_release_message' );
-has build_root => ( rw, coerce => 1, isa => Dir );
+has build_root => ( rw, coerce => 1, isa => Path );
 
 has _source_branch => (
     is      => 'ro',
@@ -87,6 +84,21 @@ sub _build_release_message { return shift->message; }
 
 # -- role implementation
 
+around dump_config => sub
+{
+    my $orig = shift;
+    my $self = shift;
+
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        map { $_ => $self->$_ }
+            qw(branch release_branch message release_message build_root multiple_inheritance),
+    };
+
+    return $config;
+};
+
 sub after_build {
     my ( $self, $args) = @_;
 
@@ -107,9 +119,9 @@ sub _commit_build {
     my ( $self, undef, $branch, $message ) = @_;
 
     return unless $branch;
-    my $tmp_dir = File::Temp->newdir( CLEANUP => 1) ;
-    my $dir     = Path::Class::Dir->new( $tmp_dir->dirname );
-    my $src     = $self->git;
+
+    my $dir = Path::Tiny->tempdir( CLEANUP => 1) ;
+    my $src = $self->git;
 
     my $target_branch = _format_branch( $branch, $self );
 
@@ -117,12 +129,9 @@ sub _commit_build {
         my ( $name, $content ) = ( $file->name, (Dist::Zilla->VERSION < 5
                                                  ? $file->content
                                                  : $file->encoded_content) );
-        my ( $outfile ) = $dir->file( $name );
+        my ( $outfile ) = $dir->child( $name );
         $outfile->parent->mkpath();
-        my $fd = $outfile->openw;
-        $fd->binmode( ":raw" );
-        $fd->print( $content );
-        $fd->close or die "error closing $outfile: $!";;
+        $outfile->spew_raw( $content );
         chmod $file->mode, "$outfile" or die "couldn't chmod $outfile: $!";
     }
 
@@ -191,13 +200,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Git::CommitBuild - checkin build results on separate branch
 
 =head1 VERSION
 
-version 2.018
+version 2.032
 
 =head1 SYNOPSIS
 
