@@ -10,17 +10,15 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::NextVersion;
-{
-  $Dist::Zilla::Plugin::Git::NextVersion::VERSION = '2.018'; # TRIAL
-}
 # ABSTRACT: provide a version number by bumping the last git release tag
+$Dist::Zilla::Plugin::Git::NextVersion::VERSION = '2.032'; # TRIAL
 
 use Dist::Zilla 4 ();
 use version 0.80 ();
 
 use Moose;
 use namespace::autoclean 0.09;
-use Path::Class qw(file);
+use Path::Tiny qw();
 use Try::Tiny;
 use Moose::Util::TypeConstraints;
 
@@ -86,7 +84,7 @@ sub _last_version {
 
   if ($by_branch) {
     my $head;
-    my $cachefile = file(_cache_fn);
+    my $cachefile = Path::Tiny::path(_cache_fn);
     if (-f $cachefile) {
       ($head) = $git->rev_parse('HEAD');
       return $1 if $cachefile->slurp =~ /^\Q$head\E (.+)/;
@@ -123,6 +121,20 @@ sub _last_version {
 
 # -- role implementation
 
+around dump_config => sub
+{
+    my $orig = shift;
+    my $self = shift;
+
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        map { $_ => $self->$_ } qw(version_regexp first_version version_by_branch),
+    };
+
+    return $config;
+};
+
 sub before_release {
   my $self = shift;
 
@@ -161,10 +173,15 @@ sub provide_version {
 sub prune_files {
   my $self = shift;
 
-  my $files = $self->zilla->files;
+  for my $file (@{ $self->zilla->files }) {
 
-  # Ensure we don't distribute .gitnxtver_cache:
-  @$files = grep { $_->name ne _cache_fn } @$files;
+    # Ensure we don't distribute .gitnxtver_cache:
+    next unless $file->name eq _cache_fn;
+
+    $self->log_debug([ 'pruning %s', $file->name ]);
+
+    $self->zilla->prune_file($file);
+  }
 
   return;
 } # end prune_files
@@ -177,13 +194,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Git::NextVersion - provide a version number by bumping the last git release tag
 
 =head1 VERSION
 
-version 2.018
+version 2.032
 
 =head1 SYNOPSIS
 
