@@ -11,10 +11,8 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::Push;
-{
-  $Dist::Zilla::Plugin::Git::Push::VERSION = '2.018'; # TRIAL
-}
 # ABSTRACT: push current branch
+$Dist::Zilla::Plugin::Git::Push::VERSION = '2.032'; # TRIAL
 
 use Moose;
 use MooseX::Has::Sugar;
@@ -44,6 +42,20 @@ has push_to => (
   default => sub { [ qw(origin) ] },
 );
 
+around dump_config => sub
+{
+    my $orig = shift;
+    my $self = shift;
+
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        map { $_ => $self->$_ } qw(push_to remotes_must_exist),
+    };
+
+    return $config;
+};
+
 sub before_release {
     my $self = shift;
 
@@ -88,13 +100,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Git::Push - push current branch
 
 =head1 VERSION
 
-version 2.018
+version 2.032
 
 =head1 SYNOPSIS
 
