@@ -11,53 +11,57 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::Tag;
-{
-  $Dist::Zilla::Plugin::Git::Tag::VERSION = '2.018'; # TRIAL
-}
 # ABSTRACT: tag the new version
+$Dist::Zilla::Plugin::Git::Tag::VERSION = '2.032'; # TRIAL
 
 use Moose;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ Str };
-use String::Formatter method_stringf => {
-  -as => '_format_tag',
-  codes => {
-    d => sub { require DateTime;
-               DateTime->now(time_zone => $_[0]->time_zone)
-                       ->format_cldr($_[1] || 'dd-MMM-yyyy') },
-    n => sub { "\n" },
-    N => sub { $_[0]->zilla->name },
-    t => sub { $_[0]->zilla->is_trial
-                 ? (defined $_[1] ? $_[1] : '-TRIAL') : '' },
-    v => sub { $_[0]->zilla->version },
-  },
-};
-
-with 'Dist::Zilla::Role::BeforeRelease';
-with 'Dist::Zilla::Role::AfterRelease';
-with 'Dist::Zilla::Role::Git::Repo';
 
+sub _git_config_mapping { +{
+   changelog => '%{changelog}s',
+} }
 
 # -- attributes
 
 has tag_format  => ( ro, isa=>Str, default => 'v%v' );
 has tag_message => ( ro, isa=>Str, default => 'v%v' );
-has time_zone   => ( ro, isa=>Str, default => 'local' );
+has changelog   => ( ro, isa=>Str, default => 'Changes' );
 has branch => ( ro, isa=>Str, predicate=>'has_branch' );
 has signed => ( ro, isa=>'Bool', default=>0 );
 
+with 'Dist::Zilla::Role::BeforeRelease';
+with 'Dist::Zilla::Role::AfterRelease';
+with 'Dist::Zilla::Role::Git::StringFormatter';
+with 'Dist::Zilla::Role::Git::Repo';
+with 'Dist::Zilla::Role::GitConfig';
+
 
 has tag => ( ro, isa => Str, lazy_build => 1, );
 
 sub _build_tag
 {
     my $self = shift;
-    return _format_tag($self->tag_format, $self);
+    return $self->_format_string($self->tag_format);
 }
 
 
 # -- role implementation
 
+around dump_config => sub
+{
+    my $orig = shift;
+    my $self = shift;
+
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        map { $_ => $self->$_ } qw(tag_format tag_message time_zone branch signed tag),
+    };
+
+    return $config;
+};
+
 sub before_release {
     my $self = shift;
 
@@ -71,7 +75,7 @@ sub after_release {
     my $self = shift;
 
     my @opts;
-    push @opts, ( '-m' => _format_tag($self->tag_message, $self) )
+    push @opts, ( '-m' => $self->_format_string($self->tag_message) )
         if $self->tag_message; # Make an annotated tag if tag_message, lightweight tag otherwise:
     push @opts, '-s'
         if $self->signed; # make a GPG-signed tag
@@ -90,13 +94,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Git::Tag - tag the new version
 
 =head1 VERSION
 
-version 2.018
+version 2.032
 
 =head1 SYNOPSIS
 
@@ -124,57 +130,27 @@ The plugin accepts the following options:
 
 =over 4
 
-=item * tag_format - format of the tag to apply. Defaults to C<v%v>, see
-C<Formatting options> below.
+=item * tag_format - format of the tag to apply. Defaults to C<v%v>.
 
-=item * tag_message - format of the tag annotation. Defaults to C<v%v>,
-see C<Formatting options> below. Use C<tag_message = > to create a
-lightweight tag.
+=item * tag_message - format of the tag annotation. Defaults to C<v%v>.
+Use S<C<tag_message =>> to create a lightweight tag.
+The L<formatting codes|Dist::Zilla::Role::Git::StringFormatter/DESCRIPTION>
+used in C<tag_format> and C<tag_message> are documented under
+L<Dist::Zilla::Role::Git::StringFormatter>.
 
 =item * time_zone - the time zone to use with C<%d>.  Can be any
 time zone name accepted by DateTime.  Defaults to C<local>.
 
-=item * branch - which branch to tag. Defaults to current branch.
+=item * branch - which branch to tag. Defaults to the current branch.
 
 =item * signed - whether to make a GPG-signed tag, using the default
-e-mail address' key. Consider setting C<user.signingkey> if C<gpg>
+e-mail address's key. Consider setting C<user.signingkey> if C<gpg>
 can't find the correct key:
 
     $ git config user.signingkey 450F89EC
 
 =back
 
-=head2 Formatting options
-
-Some plugin options allow you to customize the tag content. You can use
-the following codes at your convenience:
-
-=over 4
-
-=item C<%{dd-MMM-yyyy}d>
-
-The current date.  You can use any CLDR format supported by
-L<DateTime>. A bare C<%d> means C<%{dd-MMM-yyyy}d>.
-
-=item C<%n>
-
-A newline
-
-=item C<%N>
-
-The distribution name
-
-=item C<%{-TRIAL}t>
-
-Expands to -TRIAL (or any other supplied string) if this is a trial
-release, or the empty string if not.  A bare C<%t> means C<%{-TRIAL}t>.
-
-=item C<%v>
-
-The distribution version
-
-=back
-
 =head1 METHODS
 
 =head2 tag
