@@ -11,19 +11,17 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Role::Git::DirtyFiles;
-{
-  $Dist::Zilla::Role::Git::DirtyFiles::VERSION = '2.018'; # TRIAL
-}
 # ABSTRACT: provide the allow_dirty & changelog attributes
+$Dist::Zilla::Role::Git::DirtyFiles::VERSION = '2.032'; # TRIAL
 
 use Moose::Role;
-use Moose::Autobox;
-use MooseX::Types::Moose qw{ ArrayRef Str RegexpRef };
+use MooseX::Types::Moose qw{ Any ArrayRef Str RegexpRef };
+use MooseX::Types::Path::Tiny 0.010 qw{ Paths to_Paths };
 use Moose::Util::TypeConstraints;
 
 use namespace::autoclean;
 use List::Util 'first';
-use Path::Class;
+use Path::Tiny 0.048 qw(); # subsumes
 use Try::Tiny;
 
 requires qw(log_fatal repo_root zilla);
@@ -31,11 +29,23 @@ requires qw(log_fatal repo_root zilla);
 # -- attributes
 
 
-has allow_dirty => (
-  is => 'ro', lazy => 1,
-  isa     => ArrayRef[Str],
-  builder => '_build_allow_dirty',
-);
+{
+  # We specifically allow the empty string to represent the empty list.
+  # Otherwise, there'd be no way to specify an empty list in an INI file.
+  my $type = subtype as Paths;
+  coerce($type,
+    from ArrayRef, via { to_Paths( [ grep { length } @$_ ] ) },
+    from Any, via { length($_) ? to_Paths($_) : [] },
+  );
+
+  has allow_dirty => (
+    is => 'ro', lazy => 1,
+    isa     => $type,
+    coerce  => 1,
+    builder => '_build_allow_dirty',
+  );
+}
+
 has changelog => ( is => 'ro', isa=>Str, default => 'Changes' );
 
 {
@@ -61,7 +71,19 @@ around mvp_multivalue_args => sub {
 
 sub _build_allow_dirty { [ 'dist.ini', shift->changelog ] }
 
+around dump_config => sub
+{
+    my $orig = shift;
+    my $self = shift;
 
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        map { $_ => $self->$_ } qw(allow_dirty allow_dirty_match changelog),
+    };
+
+    return $config;
+};
 
 
 sub list_dirty_files
@@ -69,31 +91,32 @@ sub list_dirty_files
   my ($self, $git, $listAllowed) = @_;
 
   my $git_root  = $self->repo_root;
-  my @filenames = $self->allow_dirty->flatten;
+  my @filenames = @{ $self->allow_dirty };
 
   if ($git_root ne '.') {
     # Interpret allow_dirty relative to the dzil root
-    my $dzil_root = $self->zilla->root->absolute->resolve;
-    $git_root     = dir($git_root)
+    my $dzil_root = Path::Tiny::path($self->zilla->root)->absolute->realpath;
+    $git_root     = Path::Tiny::path($git_root)
                       ->absolute($dzil_root)
-                      ->resolve;
+                      ->realpath;
 
     $self->log_fatal("Dzil root $dzil_root is not inside Git root $git_root")
         unless $git_root->subsumes($dzil_root);
 
     for my $fn (@filenames) {
       try {
-        $fn = file($fn)
+        $fn = Path::Tiny::path($fn)
                 ->absolute($dzil_root)
-                ->resolve            # process ..
+                ->realpath            # process ..
                 ->relative($git_root)
-                ->as_foreign('Unix') # Git always uses Unix-style paths
                 ->stringify;
       };
     }
   } # end if git root ne dzil root
 
-  my $allowed = join '|', $self->allow_dirty_match->flatten, map { qr{^\Q$_\E$} } @filenames;
+  my $allowed = join '|', @{ $self->allow_dirty_match }, map { qr{^\Q$_\E$} } @filenames;
+
+  $allowed = qr/(?!X)X/ if $allowed eq ''; # this cannot match anything
 
   return grep { /$allowed/ ? $listAllowed : !$listAllowed }
       $git->ls_files( { modified=>1, deleted=>1 } );
@@ -106,13 +129,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::Git::DirtyFiles - provide the allow_dirty & changelog attributes
 
 =head1 VERSION
 
-version 2.018
+version 2.032
 
 =head1 DESCRIPTION
 
@@ -123,13 +148,22 @@ dirty in the local git checkout.
 
 =head2 allow_dirty
 
-A list of files that are allowed to be dirty in the git checkout.
+A list of paths that are allowed to be dirty in the git checkout.
 Defaults to C<dist.ini> and the changelog (as defined per the
 C<changelog> attribute.
 
-If your C<repo_root> is not the default (C<.>), then these filenames
+If your C<repo_root> is not the default (C<.>), then these pathnames
 are relative to Dist::Zilla's root directory, not the Git root directory.
 
+=head2 allow_dirty_match
+
+A list of regular expressions that match paths allowed to be dirty in
+the git checkout.  This is combined with C<allow_dirty>.  Defaults to
+the empty list.
+
+The paths being matched are relative to the Git root directory, even
+if your C<repo_root> is not the default (C<.>).
+
 =head2 changelog
 
 The name of the changelog. Defaults to C<Changes>.
