@@ -7,11 +7,8 @@
 # the same terms as the Perl 5 programming language system itself.
 #
 package Dist::Zilla::Role::Git::Repo;
-{
-  $Dist::Zilla::Role::Git::Repo::VERSION = '2.018'; # TRIAL
-}
-
 # ABSTRACT: Provide repository information for Git plugins
+$Dist::Zilla::Role::Git::Repo::VERSION = '2.032'; # TRIAL
 
 use Moose::Role;
 
@@ -20,6 +17,20 @@ has 'repo_root'   => ( is => 'ro', isa => 'Str', default => '.' );
 
 my %cached_wrapper;
 
+around dump_config => sub
+{
+    my $orig = shift;
+    my $self = shift;
+
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        repo_root => $self->repo_root,
+    };
+
+    return $config;
+};
+
 sub git {
   my $root = shift->repo_root;
 
@@ -35,13 +46,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::Git::Repo - Provide repository information for Git plugins
 
 =head1 VERSION
 
-version 2.018
+version 2.032
 
 =head1 DESCRIPTION
 
